@@ -1,12 +1,14 @@
 package Data::ModeMerge;
 
-our $DATE = '2015-02-21'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2016-02-25'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Dmp;
+
 use Mo qw(build default);
 
 require Exporter;
@@ -32,22 +34,15 @@ has errors => (is => "rw", default => sub { [] });
 has mem => (is => "rw", default => sub { {} }); # for handling circular refs. {key=>{res=>[...], todo=>[sub1, ...]}, ...}
 has cur_mem_key => (is => "rw"); # for handling circular refs. instead of passing around this as argument, we put it here.
 
-sub _dump {
-    require Data::Dumper;
-
-    my ($self, $var) = @_;
-    Data::Dumper->new([$var])->Indent(0)->Terse(1)->Sortkeys(1)->Dump;
-}
-
 sub _in($$) {
     my ($self, $needle, $haystack) = @_;
     return 0 unless defined($needle);
     my $r1 = ref($needle);
-    my $f1 = $r1 ? $self->_dump($needle) : undef;
+    my $f1 = $r1 ? dmp($needle) : undef;
     for (@$haystack) {
         my $r2 = ref($_);
         next if $r1 xor $r2;
-        return 1 if  $r2 && $f1 eq $self->_dump($_);
+        return 1 if  $r2 && $f1 eq dmp($_);
         return 1 if !$r2 && $needle eq $_;
     }
     0;
@@ -319,7 +314,7 @@ sub _merge {
         } else {
             $self->mem->{$memkey} = {res=>undef, todo=>[]};
             $self->cur_mem_key($memkey);
-            #print "DEBUG: invoking ".$mh->name."'s $meth(".$self->_dump($key).", ".$self->_dump($l).", ".$self->_dump($r).")\n";
+            #print "DEBUG: invoking ".$mh->name."'s $meth(".dmp($key).", ".dmp($l).", ".dmp($r).")\n";
             my ($newkey, $res, $backup) = $mh->$meth($key, $l, $r);
             #print "DEBUG: setting res for mem<$memkey>\n";
             $self->mem->{$memkey}{res} = [$newkey, $res, $backup];
@@ -328,7 +323,7 @@ sub _merge {
         }
     } else {
         $self->_process_todo;
-        #print "DEBUG: invoking ".$mh->name."'s $meth(".$self->_dump($key).", ".$self->_dump($l).", ".$self->_dump($r).")\n";
+        #print "DEBUG: invoking ".$mh->name."'s $meth(".dmp($key).", ".dmp($l).", ".dmp($r).")\n";
         return $mh->$meth($key, $l, $r);
     }
 }
@@ -360,7 +355,7 @@ Data::ModeMerge - Merge two nested data structures, with merging modes and optio
 
 =head1 VERSION
 
-This document describes version 0.32 of Data::ModeMerge (from Perl distribution Data-ModeMerge), released on 2015-02-21.
+This document describes version 0.33 of Data::ModeMerge (from Perl distribution Data-ModeMerge), released on 2016-02-25.
 
 =head1 SYNOPSIS
 
@@ -626,6 +621,38 @@ Precedence levels (from highest to lowest):
  CONCAT ADD
  DELETE
 
+=head1 CREATING AND USING YOUR OWN MODE
+
+Let's say you want to add a mode named C<FOO>. It will have the prefix
+'?'.
+
+Create the mode handler class,
+e.g. C<Data::ModeMerge::Mode::FOO>. It's probably best to subclass
+from L<Data::ModeMerge::Mode::Base>. The class must implement name(),
+precedence_level(), default_prefix(), default_prefix_re(), and
+merge_{SCALAR,ARRAY,HASH}_{SCALAR,ARRAY,HASH}(). For more details, see
+the source code of Base.pm and one of the mode handlers
+(e.g. NORMAL.pm).
+
+To use the mode, register it:
+
+ my $mm = Data::ModeMerge->new;
+ $mm->register_mode('FOO');
+
+This will require C<Data::ModeMerge::Mode::FOO>. After that, define
+the operations against other modes:
+
+ # if there's FOO on the left and NORMAL on the right, what mode
+ # should the merge be done in (FOO), and what the mode should be
+ # after the merge? (NORMAL)
+ $mm->combine_rules->{"FOO+NORMAL"} = ["FOO", "NORMAL"];
+
+ # we don't define FOO+ADD
+
+ $mm->combine_rules->{"FOO+KEEP"} = ["KEEP", "KEEP"];
+
+ # and so on
+
 =head1 FUNCTIONS
 
 =head2 mode_merge($l, $r[, $config_vars])
@@ -696,38 +723,6 @@ key is set to contain an error message if there is an error. The merge
 result is in the 'result' key. The 'backup' key contains replaced
 elements from the original hash/array.
 
-=head1 CREATING AND USING YOUR OWN MODE
-
-Let's say you want to add a mode named C<FOO>. It will have the prefix
-'?'.
-
-Create the mode handler class,
-e.g. C<Data::ModeMerge::Mode::FOO>. It's probably best to subclass
-from L<Data::ModeMerge::Mode::Base>. The class must implement name(),
-precedence_level(), default_prefix(), default_prefix_re(), and
-merge_{SCALAR,ARRAY,HASH}_{SCALAR,ARRAY,HASH}(). For more details, see
-the source code of Base.pm and one of the mode handlers
-(e.g. NORMAL.pm).
-
-To use the mode, register it:
-
- my $mm = Data::ModeMerge->new;
- $mm->register_mode('FOO');
-
-This will require C<Data::ModeMerge::Mode::FOO>. After that, define
-the operations against other modes:
-
- # if there's FOO on the left and NORMAL on the right, what mode
- # should the merge be done in (FOO), and what the mode should be
- # after the merge? (NORMAL)
- $mm->combine_rules->{"FOO+NORMAL"} = ["FOO", "NORMAL"];
-
- # we don't define FOO+ADD
-
- $mm->combine_rules->{"FOO+KEEP"} = ["KEEP", "KEEP"];
-
- # and so on
-
 =head1 FAQ
 
 =head2 What is this module good for? Why would I want to use this module instead of the other hash merge modules?
@@ -751,6 +746,22 @@ keys. I also want to be able to allow the parent to protect certain
 keys from being overriden. I found these two features lacking in all
 merging modules that I've evaluated prior to writing Data::ModeMerge.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-ModeMerge>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Data-ModeMerge>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-ModeMerge>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Data::ModeMerge::Config>
@@ -761,29 +772,13 @@ L<Hash::Merge>, L<Hash::Merge::Simple>
 L<Data::Schema> and L<Config::Tree> (among others, two modules which
 use Data::ModeMerge)
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Data-ModeMerge>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Data-ModeMerge>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-ModeMerge>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
